@@ -70,6 +70,10 @@ configDialog::configDialog(QSettings *mainSettings, QWidget *mainParent)
     item->setTextAlignment(Qt::AlignCenter);
     item->setEditable(false);
     backendModel->appendRow(item);
+    item = new QStandardItem(tr("131500.com.au"));
+    item->setTextAlignment(Qt::AlignCenter);
+    item->setEditable(false);
+    backendModel->appendRow(item);
     QMaemo5ValueButton *backendButton = new QMaemo5ValueButton(tr("Databackend"));
     backendButton->setValueLayout(QMaemo5ValueButton::ValueUnderTextCentered);
     backendSelector = new QMaemo5ListPickSelector;
@@ -87,6 +91,9 @@ configDialog::configDialog(QSettings *mainSettings, QWidget *mainParent)
     } else if (backendType == "parserSbbCh")
     {
             backendSelector->setCurrentIndex(2);
+    } else if (backendType == "parser131500ComAu")
+    {
+            backendSelector->setCurrentIndex(3);
     } else
     {
        //fallback is bahn.de
@@ -116,6 +123,8 @@ void configDialog::okButtonClicked()
     settings->setValue("storelastsearch", storelastSearchBox->isChecked());
     settings->setValue("prefillsearchbox", prefillSearchBox->isChecked());
 
+    QString oldBackend = settings->value("backend", "parserMobileBahnDe").toString();
+
     if (backendSelector->currentIndex() == 0)
     {
         settings->setValue("backend", "parserMobileBahnDe");
@@ -125,13 +134,18 @@ void configDialog::okButtonClicked()
     } else if (backendSelector->currentIndex() == 2)
     {
         settings->setValue("backend", "parserSbbCh");
+    } else if (backendSelector->currentIndex() == 3)
+    {
+        settings->setValue("backend", "parser131500ComAu");
     } else
     {
         settings->setValue("backend", "parserMobileBahnDe");
     }
 
+    QString newBackend = settings->value("backend", "parserMobileBahnDe").toString();
+
     MainWindow *mainWnd = (MainWindow*)parent;
-    mainWnd->initBackend();
+    mainWnd->initBackend(oldBackend != newBackend);
 
     hide();
 }
