@@ -20,7 +20,7 @@
     </message>
     <message>
         <location filename="mainwindow.cpp" line="46"/>
-        <location filename="mainwindow.cpp" line="313"/>
+        <location filename="mainwindow.cpp" line="322"/>
         <source>Donate</source>
         <translation>Spenden</translation>
     </message>
@@ -37,7 +37,9 @@
     <message>
         <location filename="mainwindow.cpp" line="66"/>
         <location filename="mainwindow.cpp" line="68"/>
-        <location filename="mainwindow.cpp" line="690"/>
+        <location filename="mainwindow.cpp" line="226"/>
+        <location filename="mainwindow.cpp" line="227"/>
+        <location filename="mainwindow.cpp" line="699"/>
         <source>please select</source>
         <translation>bitte wählen</translation>
     </message>
@@ -56,13 +58,13 @@
         <translation type="obsolete">- bahn.de: absturz problem behoben&lt;br&gt;- kalender auswahl verbessert&lt;br&gt;- abfahrt/ankuft knopf verbessert</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="286"/>
+        <location filename="mainwindow.cpp" line="295"/>
         <source>Arrival time</source>
         <translation>Ankunft</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="112"/>
-        <location filename="mainwindow.cpp" line="282"/>
+        <location filename="mainwindow.cpp" line="291"/>
         <source>Departure time</source>
         <translation>Abfahrt</translation>
     </message>
@@ -95,22 +97,22 @@
         <translation type="obsolete">-bahn.de: fehler mit gps suche behoben&lt;br&gt;- Geburtstags Kalender wird nun nicht mehr als wählbarer kalender angezeigt.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="224"/>
+        <location filename="mainwindow.cpp" line="233"/>
         <source>not supported</source>
         <translation>nicht unterstützt</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="248"/>
+        <location filename="mainwindow.cpp" line="257"/>
         <source>&lt;br&gt;GPS is now available!&lt;br&gt;</source>
         <translation>&lt;br&gt;GPS ist nun verfügbar!&lt;br&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="259"/>
+        <location filename="mainwindow.cpp" line="268"/>
         <source>&lt;br&gt;GPS is now &lt;b&gt;disabled&lt;/b&gt;&lt;br&gt;</source>
         <translation>&lt;br&gt;GPS ist jetzt &lt;b&gt;aus&lt;/b&gt;&lt;br&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="264"/>
+        <location filename="mainwindow.cpp" line="273"/>
         <source>&lt;br&gt;GPS is now &lt;b&gt;enabled&lt;/b&gt;&lt;br&gt;</source>
         <translation>&lt;br&gt;GPS ist jetzt &lt;b&gt;an&lt;/b&gt;&lt;br&gt;</translation>
     </message>
@@ -119,7 +121,7 @@
         <translation type="obsolete">Verbindung: </translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="455"/>
+        <location filename="mainwindow.cpp" line="464"/>
         <source> to </source>
         <translation> nach </translation>
     </message>
@@ -153,97 +155,105 @@
         <translation type="obsolete">Ziel Kalender wählen</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="190"/>
         <source>- sbb.ch: fixed parser</source>
-        <translation>- sbb.ch: fehler im parser behoben</translation>
+        <translation type="obsolete">- sbb.ch: fehler im parser behoben</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="314"/>
+        <location filename="mainwindow.cpp" line="323"/>
         <source>Thank you for Donating!</source>
         <translation>Danke fürs spenden!</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="320"/>
+        <location filename="mainwindow.cpp" line="329"/>
         <source>by smurfy (maemo@smurfy.de)&lt;br&gt;Version </source>
         <translation>von smurfy (maemo@smurfy.de)&lt;br&gt;Version </translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="320"/>
         <source>&lt;br&gt;&lt;br&gt;Current supported databackends:&lt;br&gt;&lt;b&gt;bahn.de&lt;/b&gt;, &lt;b&gt;mvv-muenchen.de&lt;/b&gt;, &lt;b&gt;sbb.ch&lt;/b&gt;&lt;br&gt;&lt;br&gt;This or prior versions uses code contribution by:&lt;br&gt;&lt;i&gt;hcm&lt;/i&gt;, &lt;i&gt;thp&lt;/i&gt;, &lt;i&gt;qwerty12&lt;/i&gt;, &lt;i&gt;qbast&lt;/i&gt;</source>
-        <translation>&lt;br&gt;&lt;br&gt;Aktuell unterstützte Datenquellen:&lt;br&gt;&lt;b&gt;bahn.de&lt;/b&gt;, &lt;b&gt;mvv-muenchen.de&lt;/b&gt;, &lt;b&gt;sbb.ch&lt;/b&gt;&lt;br&gt;&lt;br&gt;Diese oder frühere Versionen enthalten code gesponsort von:&lt;br&gt;&lt;i&gt;hcm&lt;/i&gt;, &lt;i&gt;thp&lt;/i&gt;, &lt;i&gt;qwerty12&lt;/i&gt;, &lt;i&gt;qbast&lt;/i&gt;</translation>
+        <translation type="obsolete">&lt;br&gt;&lt;br&gt;Aktuell unterstützte Datenquellen:&lt;br&gt;&lt;b&gt;bahn.de&lt;/b&gt;, &lt;b&gt;mvv-muenchen.de&lt;/b&gt;, &lt;b&gt;sbb.ch&lt;/b&gt;&lt;br&gt;&lt;br&gt;Diese oder frühere Versionen enthalten code gesponsort von:&lt;br&gt;&lt;i&gt;hcm&lt;/i&gt;, &lt;i&gt;thp&lt;/i&gt;, &lt;i&gt;qwerty12&lt;/i&gt;, &lt;i&gt;qbast&lt;/i&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="322"/>
+        <location filename="mainwindow.cpp" line="190"/>
+        <source>- adding 131500.com.au backend</source>
+        <translation>- 131500.com.au backend hinzugefügt</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="329"/>
+        <source>&lt;br&gt;&lt;br&gt;Current supported databackends:&lt;br&gt;&lt;b&gt;bahn.de&lt;/b&gt;, &lt;b&gt;mvv-muenchen.de&lt;/b&gt;, &lt;b&gt;sbb.ch&lt;/b&gt;, &lt;b&gt;131500.com.au&lt;/b&gt;&lt;br&gt;&lt;br&gt;This or prior versions uses code contribution by:&lt;br&gt;&lt;i&gt;hcm&lt;/i&gt;, &lt;i&gt;thp&lt;/i&gt;, &lt;i&gt;qwerty12&lt;/i&gt;, &lt;i&gt;qbast&lt;/i&gt;</source>
+        <translation>&lt;br&gt;&lt;br&gt;Aktuell unterstützte Datenquellen:&lt;br&gt;&lt;b&gt;bahn.de&lt;/b&gt;, &lt;b&gt;mvv-muenchen.de&lt;/b&gt;, &lt;b&gt;sbb.ch&lt;/b&gt;, &lt;b&gt;131500.com.au&lt;/b&gt;&lt;br&gt;&lt;br&gt;Diese oder frühere Versionen enthalten code gesponsort von:&lt;br&gt;&lt;i&gt;hcm&lt;/i&gt;, &lt;i&gt;thp&lt;/i&gt;, &lt;i&gt;qwerty12&lt;/i&gt;, &lt;i&gt;qbast&lt;/i&gt;</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="331"/>
         <source>About Fahrplan</source>
         <translation>Über Fahrplan</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="349"/>
+        <location filename="mainwindow.cpp" line="358"/>
         <source>&lt;br&gt;Details already loading, please wait.&lt;br&gt;</source>
         <translation>&lt;br&gt;Details werden bereits geladen, bitte warten.&lt;br&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="363"/>
+        <location filename="mainwindow.cpp" line="372"/>
         <source>&lt;br&gt;Error opening the details.&lt;br&gt;</source>
         <translation>&lt;br&gt;Beim öffnen der Details ist ein Fehler aufgetreten.&lt;br&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="369"/>
+        <location filename="mainwindow.cpp" line="378"/>
         <source>Details</source>
         <translation>Details</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="378"/>
+        <location filename="mainwindow.cpp" line="387"/>
         <source>Add to calendar</source>
         <translation>In Kalender eintragen</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="460"/>
+        <location filename="mainwindow.cpp" line="469"/>
         <source>&lt;br&gt;&lt;b&gt;Duration: &lt;/b&gt;</source>
         <translation>&lt;br&gt;&lt;b&gt;Dauer: &lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="495"/>
+        <location filename="mainwindow.cpp" line="504"/>
         <source>&lt;br&gt;No results found.&lt;br&gt;</source>
         <translation>&lt;br&gt;Keine Ergebnisse gefunden.&lt;br&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="514"/>
+        <location filename="mainwindow.cpp" line="523"/>
         <source>Results</source>
         <translation>Ergebnis</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="531"/>
+        <location filename="mainwindow.cpp" line="540"/>
         <source>to</source>
         <translation>nach</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="542"/>
+        <location filename="mainwindow.cpp" line="551"/>
         <source>Earlier</source>
         <translation>Früher</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="548"/>
+        <location filename="mainwindow.cpp" line="557"/>
         <source>Later</source>
         <translation>Später</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="561"/>
+        <location filename="mainwindow.cpp" line="570"/>
         <source> transfer</source>
         <translation> umstieg</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="564"/>
+        <location filename="mainwindow.cpp" line="573"/>
         <source> transfers</source>
         <translation> umstiege</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="583"/>
+        <location filename="mainwindow.cpp" line="592"/>
         <source>&lt;br&gt;OnTime</source>
         <translation>&lt;br&gt;Pünktlich</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="720"/>
+        <location filename="mainwindow.cpp" line="729"/>
         <source>&lt;br&gt;Please select a from and to station and make sure they are not the same.&lt;br&gt;</source>
         <translation>&lt;br&gt;Bitte zwei verschiedene Haltestellen wählen.&lt;br&gt;</translation>
     </message>
@@ -361,10 +371,43 @@
     </message>
     <message>
         <location filename="configdialog.cpp" line="73"/>
+        <source>131500.com.au</source>
+        <translation>131500.com.au</translation>
+    </message>
+    <message>
+        <location filename="configdialog.cpp" line="77"/>
         <source>Databackend</source>
         <translation>Datenquelle</translation>
     </message>
 </context>
+<context>
+    <name>parser131500ComAu</name>
+    <message>
+        <location filename="parser_131500comau.cpp" line="95"/>
+        <source>All, except School Buses</source>
+        <translation>Alles, ausser Schulbusse</translation>
+    </message>
+    <message>
+        <location filename="parser_131500comau.cpp" line="96"/>
+        <source>Regular Buses</source>
+        <translation>Normale Busse</translation>
+    </message>
+    <message>
+        <location filename="parser_131500comau.cpp" line="97"/>
+        <source>Trains</source>
+        <translation>Züge</translation>
+    </message>
+    <message>
+        <location filename="parser_131500comau.cpp" line="98"/>
+        <source>Ferries</source>
+        <translation>Fähren</translation>
+    </message>
+    <message>
+        <location filename="parser_131500comau.cpp" line="99"/>
+        <source>STA School Bus</source>
+        <translation>Schulbusse</translation>
+    </message>
+</context>
 <context>
     <name>parserMobileBahnDe</name>
     <message>
