@@ -187,14 +187,14 @@ MainWindow::MainWindow(QWidget *parent)
     {
         QMessageBox::about(this,
                            tr("Welcome to a new version of fahrplan this has changed"),
-                           tr("- sbb.ch: fixed parser")
+                           tr("- adding 131500.com.au backend")
                            );
 
         settings->setValue("firstLaunch", APP_VER);
     }
 }
 
-void MainWindow::initBackend()
+void MainWindow::initBackend(bool resetStations)
 {
     QString backendType = settings->value("backend", "parserMobileBahnDe").toString();
 
@@ -211,6 +211,10 @@ void MainWindow::initBackend()
     {
         backendParser = new parserSbbCh();
         setWindowTitle("Fahrplan (sbb.ch)");
+    } else if (backendType == "parser131500ComAu")
+    {
+        backendParser = new parser131500ComAu();
+        setWindowTitle("Fahrplan (131500.com.au)");
     } else
     {
        //fallback is bahn.de
@@ -218,6 +222,11 @@ void MainWindow::initBackend()
        setWindowTitle("Fahrplan (bahn.de)");
     }
 
+    if (resetStations) {
+        stationArrival->setValueText(tr("please select"));
+        stationDeparture->setValueText(tr("please select"));
+    }
+
     //Update gui based on Backend
     QStringList trainRestrictions = backendParser->getTrainRestrictions();
     traintypesButton->setPickSelector(NULL);
@@ -317,7 +326,7 @@ void MainWindow::donateButtonClicked()
 void MainWindow::aboutButtonClicked()
 {
     QString version = APP_VER;
-    QString aboutMsg = tr("by smurfy (maemo@smurfy.de)<br>Version ") + version + tr("<br><br>Current supported databackends:<br><b>bahn.de</b>, <b>mvv-muenchen.de</b>, <b>sbb.ch</b><br><br>This or prior versions uses code contribution by:<br><i>hcm</i>, <i>thp</i>, <i>qwerty12</i>, <i>qbast</i>");
+    QString aboutMsg = tr("by smurfy (maemo@smurfy.de)<br>Version ") + version + tr("<br><br>Current supported databackends:<br><b>bahn.de</b>, <b>mvv-muenchen.de</b>, <b>sbb.ch</b>, <b>131500.com.au</b><br><br>This or prior versions uses code contribution by:<br><i>hcm</i>, <i>thp</i>, <i>qwerty12</i>, <i>qbast</i>");
     QMessageBox::about(this,
                        tr("About Fahrplan"),
                        tr(aboutMsg.toAscii()));
