@@ -24,8 +24,8 @@
 #include <QMainWindow>
 #include <QtGui>
 #include <QtMaemo5>
-#include <qgtkstyle.h>
 #include <QMaemo5InformationBox>
+#include <qgtkstyle.h>
 #include <QtCore/QtGlobal>
 #include <QtCore/QtDebug>
 
@@ -40,11 +40,12 @@
 #include "parser_mobilebahnde.h"
 #include "parser_mvvde.h"
 #include "parser_sbbch.h"
+#include "parser_131500comau.h"
 #include "selectstationdialog.h"
 #include "configdialog.h"
 #include "calendardialog.h"
 
-#define APP_VER "0.0.18"
+#define APP_VER "0.0.19"
 
 //Use the QtMobility namespace
 QTM_USE_NAMESPACE
@@ -68,7 +69,7 @@ class MainWindow : public QMainWindow
 
 public:
     explicit MainWindow(QWidget *parent=0);
-    void initBackend();
+    void initBackend(bool resetStations = false);
 
 public slots:
     void positionUpdated(QGeoPositionInfo geoPositionInfo);
